usb: rename board_usb_init_type to usb_init_type

This will be used by usb_lowlevel_init so it will
no longer be used by only board specific functions.

Move definition of enum usb_init_type higher in file
so that it will be available for usb_low_level_init.

Signed-off-by: Troy Kisky <troy.kisky@boundarydevices.com>
diff --git a/include/usb.h b/include/usb.h
index 17fb68c..b4fea52 100644
--- a/include/usb.h
+++ b/include/usb.h
@@ -129,6 +129,16 @@
 	unsigned int slot_id;
 };
 
+/*
+ * You can initialize platform's USB host or device
+ * ports by passing this enum as an argument to
+ * board_usb_init().
+ */
+enum usb_init_type {
+	USB_INIT_HOST,
+	USB_INIT_DEVICE
+};
+
 /**********************************************************************
  * this is how the lowlevel part communicate with the outer world
  */
@@ -170,32 +180,22 @@
 #endif
 
 /*
- * You can initialize platform's USB host or device
- * ports by passing this enum as an argument to
- * board_usb_init().
- */
-enum board_usb_init_type {
-	USB_INIT_HOST,
-	USB_INIT_DEVICE
-};
-
-/*
  * board-specific hardware initialization, called by
  * usb drivers and u-boot commands
  *
  * @param index USB controller number
  * @param init initializes controller as USB host or device
  */
-int board_usb_init(int index, enum board_usb_init_type init);
+int board_usb_init(int index, enum usb_init_type init);
 
 /*
  * can be used to clean up after failed USB initialization attempt
  * vide: board_usb_init()
  *
  * @param index USB controller number for selective cleanup
  * @param init board_usb_init_type passed to board_usb_init()
  */
-int board_usb_cleanup(int index, enum board_usb_init_type init);
+int board_usb_cleanup(int index, enum usb_init_type init);
 
 #ifdef CONFIG_USB_STORAGE
@@ -170,32 +180,22 @@
  *
  * @param index USB controller number for selective cleanup
- * @param init board_usb_init_type passed to board_usb_init()
+ * @param init usb_init_type passed to board_usb_init()
  */